# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.gdchardwaremanagement import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.gdchardwaremanagement_v1alpha.services.gdc_hardware_management.async_client import (
    GDCHardwareManagementAsyncClient,
)
from google.cloud.gdchardwaremanagement_v1alpha.services.gdc_hardware_management.client import (
    GDCHardwareManagementClient,
)
from google.cloud.gdchardwaremanagement_v1alpha.types.resources import (
    ChangeLogEntry,
    Comment,
    Contact,
    Dimensions,
    Entity,
    Hardware,
    HardwareConfig,
    HardwareGroup,
    HardwareInstallationInfo,
    HardwareLocation,
    HardwarePhysicalInfo,
    Order,
    OrganizationContact,
    PowerSupply,
    RackSpace,
    Site,
    Sku,
    SkuConfig,
    SkuInstance,
    Subnet,
    SubscriptionConfig,
    TimePeriod,
    Zone,
    ZoneNetworkConfig,
)
from google.cloud.gdchardwaremanagement_v1alpha.types.service import (
    CreateCommentRequest,
    CreateHardwareGroupRequest,
    CreateHardwareRequest,
    CreateOrderRequest,
    CreateSiteRequest,
    CreateZoneRequest,
    DeleteHardwareGroupRequest,
    DeleteHardwareRequest,
    DeleteOrderRequest,
    DeleteSiteRequest,
    DeleteZoneRequest,
    GetChangeLogEntryRequest,
    GetCommentRequest,
    GetHardwareGroupRequest,
    GetHardwareRequest,
    GetOrderRequest,
    GetSiteRequest,
    GetSkuRequest,
    GetZoneRequest,
    ListChangeLogEntriesRequest,
    ListChangeLogEntriesResponse,
    ListCommentsRequest,
    ListCommentsResponse,
    ListHardwareGroupsRequest,
    ListHardwareGroupsResponse,
    ListHardwareRequest,
    ListHardwareResponse,
    ListOrdersRequest,
    ListOrdersResponse,
    ListSitesRequest,
    ListSitesResponse,
    ListSkusRequest,
    ListSkusResponse,
    ListZonesRequest,
    ListZonesResponse,
    OperationMetadata,
    RecordActionOnCommentRequest,
    SignalZoneStateRequest,
    SubmitOrderRequest,
    UpdateHardwareGroupRequest,
    UpdateHardwareRequest,
    UpdateOrderRequest,
    UpdateSiteRequest,
    UpdateZoneRequest,
)

__all__ = (
    "GDCHardwareManagementClient",
    "GDCHardwareManagementAsyncClient",
    "ChangeLogEntry",
    "Comment",
    "Contact",
    "Dimensions",
    "Hardware",
    "HardwareConfig",
    "HardwareGroup",
    "HardwareInstallationInfo",
    "HardwareLocation",
    "HardwarePhysicalInfo",
    "Order",
    "OrganizationContact",
    "RackSpace",
    "Site",
    "Sku",
    "SkuConfig",
    "SkuInstance",
    "Subnet",
    "SubscriptionConfig",
    "TimePeriod",
    "Zone",
    "ZoneNetworkConfig",
    "Entity",
    "PowerSupply",
    "CreateCommentRequest",
    "CreateHardwareGroupRequest",
    "CreateHardwareRequest",
    "CreateOrderRequest",
    "CreateSiteRequest",
    "CreateZoneRequest",
    "DeleteHardwareGroupRequest",
    "DeleteHardwareRequest",
    "DeleteOrderRequest",
    "DeleteSiteRequest",
    "DeleteZoneRequest",
    "GetChangeLogEntryRequest",
    "GetCommentRequest",
    "GetHardwareGroupRequest",
    "GetHardwareRequest",
    "GetOrderRequest",
    "GetSiteRequest",
    "GetSkuRequest",
    "GetZoneRequest",
    "ListChangeLogEntriesRequest",
    "ListChangeLogEntriesResponse",
    "ListCommentsRequest",
    "ListCommentsResponse",
    "ListHardwareGroupsRequest",
    "ListHardwareGroupsResponse",
    "ListHardwareRequest",
    "ListHardwareResponse",
    "ListOrdersRequest",
    "ListOrdersResponse",
    "ListSitesRequest",
    "ListSitesResponse",
    "ListSkusRequest",
    "ListSkusResponse",
    "ListZonesRequest",
    "ListZonesResponse",
    "OperationMetadata",
    "RecordActionOnCommentRequest",
    "SignalZoneStateRequest",
    "SubmitOrderRequest",
    "UpdateHardwareGroupRequest",
    "UpdateHardwareRequest",
    "UpdateOrderRequest",
    "UpdateSiteRequest",
    "UpdateZoneRequest",
)
